@@ -29,7 +29,15 @@ References
 # copyright: (c) 2014 James Spencer
 # license: modified BSD license; see LICENSE for further details.
 
+import warnings
 # For convenience, import all submodules so the user need only import pyblock.
 import pyblock.error
 import pyblock.blocking
-import pyblock.pd_utils
+try:
+    import pyblock.pd_utils
+except ImportError:
+    warnings.warn('Pandas wrappers disabled: pandas not available.')
+try:
+    import pyblock.plot
+except ImportError:
+    warnings.warn('Plotting disabled: matplotlib not available.')
